@@ -39,9 +39,9 @@ class KSGKipiImageCollectionSelector : public KIPI::ImageCollectionSelector
     public:
 
     explicit KSGKipiImageCollectionSelector(KIPI::Interface *interface, QWidget *parent);
-    ~KSGKipiImageCollectionSelector() Q_DECL_OVERRIDE;
+    ~KSGKipiImageCollectionSelector() override;
 
-    QList<KIPI::ImageCollection> selectedImageCollections() const Q_DECL_OVERRIDE;
+    QList<KIPI::ImageCollection> selectedImageCollections() const override;
 
     private:
 
