@@ -38,6 +38,7 @@
 #include <QDir>
 #include <QDrag>
 #include <QMimeData>
+#include <QProcess>
 #include <QTimer>
 
 SpectacleCore::SpectacleCore(StartMode startMode, ImageGrabber::GrabMode grabMode, QString &saveFileName,
@@ -84,6 +85,12 @@ SpectacleCore::SpectacleCore(StartMode startMode, ImageGrabber::GrabMode grabMod
         delayMsec = 0;
     }
 
+    //Reset last region if it should not be remembered across restarts
+    SpectacleConfig* cfg = SpectacleConfig::instance();
+    if(!cfg->alwaysRememberRegion()) {
+        cfg->setCropRegion(QRect());
+    }
+
     connect(mExportManager, &ExportManager::errorMessage, this, &SpectacleCore::showErrorMessage);
     connect(this, &SpectacleCore::errorMessage, this, &SpectacleCore::showErrorMessage);
     connect(mImageGrabber, &ImageGrabber::pixmapChanged, this, &SpectacleCore::screenshotUpdated);
@@ -133,7 +140,7 @@ ImageGrabber::GrabMode SpectacleCore::grabMode() const
     return mImageGrabber->grabMode();
 }
 
-void SpectacleCore::setGrabMode(const ImageGrabber::GrabMode &grabMode)
+void SpectacleCore::setGrabMode(ImageGrabber::GrabMode grabMode)
 {
     mImageGrabber->setGrabMode(grabMode);
     mExportManager->setGrabMode(grabMode);
@@ -146,7 +153,22 @@ void SpectacleCore::dbusStartAgent()
     qApp->setQuitOnLastWindowClosed(true);
     if (!(mStartMode == GuiMode)) {
         mStartMode = GuiMode;
-        return initGui();
+        initGui();
+    } else {
+        using Actions = SpectacleConfig::PrintKeyActionRunning;
+        switch (SpectacleConfig::instance()->printKeyActionRunning()) {
+            case Actions::TakeNewScreenshot:
+                QTimer::singleShot(KWindowSystem::compositingActive() ? 200 : 50, mImageGrabber, &ImageGrabber::doImageGrab);
+                break;
+            case Actions::FocusWindow:
+                KWindowSystem::forceActiveWindow(mMainWindow->winId());;
+                break;
+            case Actions::StartNewInstance:
+                QProcess newInstance;
+                newInstance.setProgram(QStringLiteral("spectacle"));
+                newInstance.startDetached();
+                break;
+        }
     }
 }
 
@@ -304,7 +326,7 @@ void SpectacleCore::doStartDragAndDrop()
 void SpectacleCore::initGui()
 {
     if (!isGuiInited) {
-        mMainWindow = new KSMainWindow(mImageGrabber->onClickGrabSupported());
+        mMainWindow = new KSMainWindow(mImageGrabber->supportedModes(), mImageGrabber->onClickGrabSupported());
 
         connect(mMainWindow, &KSMainWindow::newScreenshotRequest, this, &SpectacleCore::takeNewScreenshot);
         connect(mMainWindow, &KSMainWindow::dragAndDropRequest, this, &SpectacleCore::doStartDragAndDrop);
